@@ -309,9 +309,12 @@ html_box_text_accessible_get_character_at_offset (AtkText *text,
 	gchar *index;
 	gunichar unichar;
 
-	g_return_val_if_fail (HTML_IS_BOX_TEXT_ACCESSIBLE (text), 0);
+	g_return_val_if_fail (HTML_IS_BOX_TEXT_ACCESSIBLE (text), '\0');
 	text_accessible = HTML_BOX_TEXT_ACCESSIBLE (text);
 	buffer = text_accessible->priv->textutil->buffer;
+	if (offset >= gtk_text_buffer_get_char_count (buffer))
+		return '\0';
+
 	gtk_text_buffer_get_start_iter (buffer, &start);
 	gtk_text_buffer_get_end_iter (buffer, &end);
 	string = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
