@@ -71,7 +71,7 @@ static GtkLayoutClass *parent_class = NULL;
 static gboolean html_view_remove_layout_box (HtmlView *view, DomNode *node);
 static void html_view_try_jump (HtmlView *view);
 static void html_view_set_saved_focus (HtmlView *view);
-static DomElement* html_view_get_saved_focus (HtmlView *view);
+static DomElement* html_view_get_and_unset_saved_focus (HtmlView *view);
 static void html_view_focus_element (HtmlView *view);
 
 #ifdef ENABLE_ACCESSIBILITY
@@ -744,7 +744,7 @@ html_view_focus_in (GtkWidget *widget, GdkEventFocus *event)
 
 	view = HTML_VIEW (widget);
 
-	element = html_view_get_saved_focus (view);
+	element = html_view_get_and_unset_saved_focus (view);
 	if (element) {
 		html_document_update_focus_element (view->document, element);
 	}
@@ -817,9 +817,9 @@ html_view_focus (GtkWidget *widget, GtkDirectionType direction)
 		return FALSE;
 	}
 
+
 	if (direction == GTK_DIR_TAB_FORWARD) {
 		html_document_update_focus_element (view->document, html_focus_iterator_next_element (view->document->dom_document, view->document->focus_element));
-			
 		if (view->document->focus_element) {
 			html_view_focus_element (view);
 			return TRUE;
@@ -1227,14 +1227,18 @@ html_view_set_saved_focus (HtmlView *view)
 }
 
 static DomElement* 
-html_view_get_saved_focus (HtmlView *view)
+html_view_get_and_unset_saved_focus (HtmlView *view)
 {
 	gpointer saved_focus;
 	
 	saved_focus = g_object_get_data (G_OBJECT (view), "saved-focus");
-	if (saved_focus)
+	if (saved_focus) {
+		g_object_weak_unref (G_OBJECT (saved_focus),
+				     (GWeakNotify) focus_element_destroyed,
+				     view);
+		g_object_set_data (G_OBJECT (view), "saved-focus", NULL);
 		return DOM_ELEMENT (saved_focus);
-	else
+	} else
 		return NULL;
 }
 
